@@ -63,9 +63,9 @@ if __name__ == "__main__":
     # zip_dir(ZVT_TEST_DATA_PATH, zip_file_name=DATA_SAMPLE_ZIP_PATH)
     # gen_exports('contract',export_modules=['schema'])
     # gen_exports("ml")
-    gen_exports("utils")
-    # gen_exports('recorders')
-    # gen_exports('domain')
+    # gen_exports("utils")
+    gen_exports("recorders/em")
+    gen_exports("domain")
     # gen_exports('informer')
     # gen_exports('api')
     # gen_exports('trader')
